{% extends "fluent_faq/base_detail.html" %}
{% load i18n fluent_contents_tags %}

{% block content %}
    <section class="faq-question-detail">
      <article class="faq-question">
        <header>
          <h2>{{ object.title }}</h2>
        </header>

        <div class="faq-question-body">
          {% render_placeholder object.contents %}
        </div>
      </article>
    </section>
{% endblock %}


{% block sidebar_content %}
    {% include "fluent_faq/partials/similar_questions.html" %}
{% endblock %}
