{% extends "fluent_faq/base_detail.html" %}
{% load fluent_faq_tags i18n %}

{% block content %}
  <h2>{{ object.title }}</h2>

  {% with questions=object.faq_questions %}
    {% if not questions %}
      {% trans "There are no questions in this category yet." %}
    {% else %}
      <ul class="faq-questions">
      {% for question in questions %}
        <li><a href="{% get_faq_url question %}">{{ question.title }}</a></li>
      {% endfor %}
      </ul>
    {% endif %}
  {% endwith %}
{% endblock %}
